
Supporting Standards
====================

The section contains modules that implement supporting specifications that are not specific, or at least have no special interest in the domains of Learning, Education and Training.

Contents:

.. toctree::
   :maxdepth: 2

   odatav2
   xml20081126
   xml20081126.parser
   xsdatatypes20041028
   html40_19991224
   rfc2396
   rfc2616
   rfc4287
   rfc5023
   iso8601